Title: Read 'SurveyXact' Data
Version: 0.8.8
Description: Imports data from the 'SurveyXact' commercial service https://rambollxact.com, adds variable labels, and converts value labels to factors in the same order as exported from 'SurveyXact'.
License: MIT + file LICENSE
URL: https://github.com/NIFU-NO/readSX, https://NIFU-NO.github.io/readSX/
BugReports: https://github.com/NIFU-NO/readSX/issues
Depends: R (≥ 3.10)
Imports: cli, readxl, rlang, utils
Suggests: covr, testthat (≥ 3.0.0)
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.3
Language: en-US
NeedsCompilation: no
Packaged: 2026-03-14 09:49:38 UTC; py128
Author: Stephan Daus ORCID iD [aut, cre]
Maintainer: Stephan Daus <stephus.daus@gmail.com>
Repository: CRAN
Date/Publication: 2026-03-14 16:20:08 UTC

readSX: Read 'SurveyXact' Data

Description

Imports data from the 'SurveyXact' commercial service https://rambollxact.com, adds variable labels, and converts value labels to factors in the same order as exported from 'SurveyXact'.

Author(s)

Maintainer: Stephan Daus stephus.daus@gmail.com (ORCID)

See Also

Useful links:


Checks If Filepath is Valid, Optionally Fixes It.

Description

Checks If Filepath is Valid, Optionally Fixes It.

Usage

check_filepath(filepath = filepath)

Arguments

filepath

Character vector of filepaths to check.

Value

filepath as a named character vector


Import Data Generated by SurveyXact

Description

First export the data from SurveyXact either as Excel or a set of CSV-files in European format (semicolon-sep). Then import using this function while setting variable labels and value labels automatically. Can then use labelled-package or other functions in this package for further processing.

Usage

read_surveyxact(
  filepath = c(dataset = "dataset.csv", structure = "structure.csv", labels =
    "labels.csv"),
  trim_ws = FALSE
)

Arguments

filepath

A character string with a path to an Excel file, or a character vector with paths to the dataset.csv, structure.csv and labels.csv-files.

trim_ws

Logical, default is FALSE. Whether to remove leading and ending whitespace from all files.

Value

data.frame.

Examples

dataset <- system.file("extdata", "ex_survey2_tab_utf16", "dataset.csv",
  package = "readSX", mustWork = TRUE
)
labels <- system.file("extdata", "ex_survey2_tab_utf16", "labels.csv",
  package = "readSX", mustWork = TRUE
)
structure <- system.file("extdata", "ex_survey2_tab_utf16", "structure.csv",
  package = "readSX", mustWork = TRUE
)
ex_survey2_tab_utf16 <-
  read_surveyxact(filepath = c(
    dataset = dataset,
    labels = labels,
    structure = structure
  ))

Writes Data with Respondents in CSV Format Required for SurveyXact Import

Description

Writes Data with Respondents in CSV Format Required for SurveyXact Import

Usage

write_data_for_sx(data, filepath, overwrite = FALSE)

Arguments

data

Data frame (or tibble).

filepath

Filepath as string

overwrite

Whether to overwrite existing file or not (default).

Value

Side-effect: writes file. Returns filepath.

Examples

tmpfile <- tempfile(fileext = ".csv")
write_data_for_sx(mtcars, filepath=tmpfile)
unlink(tmpfile)